import React, { Component } from 'react';
import { View, Text, Picker, Platform, Modal, TouchableWithoutFeedback } from 'react-native';
import PropTypes from 'prop-types';
import { SimpleLineIcons } from '@expo/vector-icons';
import _ from 'lodash';

import Button from '../components/Button';

export default class Select extends Component {
  static propTypes = {
    children: PropTypes.oneOfType([
      PropTypes.element,
      PropTypes.array
    ]).isRequired,
    label: PropTypes.string.isRequired,
    value: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.number
    ]),
    onChange: PropTypes.func,
    labelColor: PropTypes.string,
    marginTop: PropTypes.number,
    buttonBackgroundColor: PropTypes.string,
    buttonTextColor: PropTypes.string,
    name: PropTypes.string
  };

  static defaultProps = {
    value: '',
    onChange: () => {},
    labelColor: '#3c4f5e',
    marginTop: 0,
    buttonBackgroundColor: '#1d1d1d',
    buttonTextColor: '#ffffff',
    name: ''
  };

  state = {
    isModalVisible: false,
    value: this.props.value.toString(),
    index: 0
  };

  onPressItemLabel = () => {
    this.setState({
      isModalVisible: true
    });
  };

  onPressSelect = () => {
    this.props.onChange(this.state.value, this.state.index, this.props.name);

    this.setState({
      isModalVisible: false
    });
  };

  onPressCancel = () => {
    this.setState({
      isModalVisible: false,
      value: this.props.value
    });
  };

  onChange = (value, index) => {
    if (Platform.OS == 'android') {
      this.props.onChange(value, index, this.props.name);
    }
    else {
      this.setState({
        value: value,
        index: index
      });
    }
  };

  render() {
    if (Platform.OS == 'android') {
      return (
        <View style={{ marginTop: this.props.marginTop, height: 60, flexDirection: 'row' }}>
          <View style={{ flex: 1, justifyContent: 'center' }}>
            <Text style={{ color: this.props.labelColor }}>{ this.props.label }</Text>
          </View>
          <View style={{ flex: 2, justifyContent: 'center' }}>
            <Picker
              selectedValue={this.props.value.toString()}
              onValueChange={this.onChange}
            >
              { this.props.children }
            </Picker>
          </View>
        </View>
      );
    }
    else {
      let index = _.findIndex(this.props.children, (child) => {
        return child.props.value == this.props.value;
      });

      if (index == -1) {
        index = 0;
      }

      const label = this.props.children[index].props.label;

      return (
        <View style={{ marginTop: this.props.marginTop, height: 60, flexDirection: 'row' }}>
          <Modal
            animationType="fade"
            transparent
            visible={this.state.isModalVisible}
          >
            <View style={{ flex: 1, justifyContent: 'center', backgroundColor: 'rgba(0, 0, 0, 0.5)' }}>
              <View style={{ height: 300, paddingHorizontal: 30 }}>
                <View style={{ backgroundColor: '#fcfcfc', borderRadius: 5 }}>
                  <View style={{ paddingHorizontal: 30 }}>
                    <Picker
                      selectedValue={this.state.value}
                      onValueChange={this.onChange}
                    >
                      { this.props.children }
                    </Picker>
                  </View>
                  <Text style={{ position: 'absolute', top: 20, left: 20 }}>{ this.props.label }</Text>
                  <TouchableWithoutFeedback onPress={this.onPressCancel}>
                    <View style={{ width: 60, height: 60, position: 'absolute', top: 0, right: 0 }}>
                      <Text style={{ color: '#007aff', position: 'absolute', top: 20, right: 20 }}>취소</Text>
                    </View>
                  </TouchableWithoutFeedback>
                  <View style={{ paddingHorizontal: 50 }}>
                    <Button backgroundColor={this.props.buttonBackgroundColor} textColor={this.props.buttonTextColor} onPress={this.onPressSelect}>선택</Button>
                  </View>
                  <View style={{ height: 20 }} />
                </View>
              </View>
            </View>
          </Modal>
          <View style={{ flex: 1, justifyContent: 'center' }}>
            <Text>{ this.props.label }</Text>
          </View>
          <TouchableWithoutFeedback onPress={this.onPressItemLabel}>
            <View style={{ flex: 2, flexDirection: 'row' }}>
              <View style={{ flex: 1, justifyContent: 'center' }}>
                <Text style={{ color: this.props.labelColor }}>{ label }</Text>
              </View>
              <View style={{ width: 60, height: 60, alignItems: 'center', justifyContent: 'center' }}>
                <SimpleLineIcons name="arrow-down" size={23} color="#3c4f5e" />
              </View>
            </View>
          </TouchableWithoutFeedback>
        </View>
      );
    }
  }
}
